@@ -106,10 +106,11 @@ def render_diff(config_path: str = "mt_config.json"):
 
 
 @app.command()
-def create_config(config_path="./mt_config.json"):
+def init(config_path="./mt_config.json"):
     schema_url = "https://raw.githubusercontent.com/Perlten/MT-diagrams/master/config.template.json"
     os.makedirs(os.path.dirname(config_path), exist_ok=True)
     schema = requests.get(schema_url).json()
+    schema["name"] = os.path.basename(os.getcwd())
     with open(config_path, "w") as outfile:
         json.dump(schema, outfile, indent=4)
 
